==> parodia_admin-1.0.2.tar.gz: lib/core/repository/photo.repository.dart <==
// GET
// /api/v1/dashboard/photos/{id}

// PUT
// /api/v1/dashboard/photos/{id}

// DELETE
// /api/v1/dashboard/photos/{id}

// GET
// /api/v1/dashboard/photos

// POST
// /api/v1/dashboard/photos

// POST
// /api/v1/dashboard/photos/multiple

// POST
// /api/v1/dashboard/photos/{id}/recover

import 'package:parodia_admin/core/dto/photo.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class PhotoRepository {
  ParodiaHTTP? _http;

  PhotoRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<PhotoDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/photos',
      param: id,
    );

    return ResponseItemDTO<PhotoDTO>(
      response: response,
      fromJson: PhotoDTO.fromJson,
    );
  }

  Future<ResponseListDTO<PhotoDTO>> getAll({PhotoQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/photos',
      query: query,
    );

    return ResponseListDTO<PhotoDTO>(
      response: response,
      fromJson: PhotoDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({PhotoBody? photo}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/photos',
      data: photo,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, PhotoMultipleBody? photos}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/photos/multiple',
      data: photos,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, PhotoBody? photo}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/photos',
      param: id,
      data: photo,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/photos',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/photos/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.5.tar.gz: lib/core/repository/photo.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/photos/{id}

// PUT
// /api/v1/dashboard/dashboard/photos/{id}

// DELETE
// /api/v1/dashboard/dashboard/photos/{id}

// GET
// /api/v1/dashboard/dashboard/photos

// POST
// /api/v1/dashboard/dashboard/photos

// POST
// /api/v1/dashboard/dashboard/photos/multiple

// POST
// /api/v1/dashboard/dashboard/photos/{id}/recover

import 'package:parodia_admin/core/dto/photo.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class PhotoRepository {
  ParodiaHTTP? _http;

  PhotoRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<PhotoDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/photos',
      param: id,
    );

    return ResponseItemDTO<PhotoDTO>(
      response: response,
      fromJson: PhotoDTO.fromJson,
    );
  }

  Future<ResponseListDTO<PhotoDTO>> getAll({PhotoQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/photos',
      query: query,
    );

    return ResponseListDTO<PhotoDTO>(
      response: response,
      fromJson: PhotoDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({PhotoBody? photo}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/photos',
      data: photo,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, PhotoMultipleBody? photos}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/photos/multiple',
      data: photos,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, PhotoBody? photo}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/photos',
      param: id,
      data: photo,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/photos',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/photos/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
